@@ -9,7 +9,9 @@ var os = require('os'),
     path = require('path'),
     child_process = require('child_process'),
     properLock = require('proper-lockfile'),
-    crypto = require('crypto');
+    crypto = require('crypto'),
+    cluster = require('cluster');
+
 
 const RequestLog = require('../requestlog');
 
@@ -364,6 +366,9 @@ NodeAgent.prototype.openPortFile = function(filepath) {
  * @returns {number|null} - Allocated port number or null if failed
  */
 NodeAgent.prototype.getPortNumber = function(port, home) {
+    // Node.js cluster 모드 감지 (isPM2ClusterMode 호출 전에 실행)
+    this.isClusterMode();
+
     port = port || 6600;
     home = home || process.env.WHATAP_HOME;
 
@@ -615,6 +620,29 @@ NodeAgent.prototype.updateConfig = function(home, optKey, optValue) {
     }
 };
 
+/**
+ * Detect Node.js cluster mode and set environment variables
+ * This allows Node.js cluster to work the same way as PM2 cluster mode
+ */
+NodeAgent.prototype.isClusterMode = function() {
+    // PM2 환경 변수가 이미 있으면 skip
+    if (process.env.pm_id !== undefined) {
+        return;
+    }
+
+    // Node.js cluster worker인 경우 PM2 cluster 형태로 환경 변수 설정
+    if (cluster.worker) {
+        process.env.pm_id = cluster.worker.id.toString();
+
+        // instances 값은 실제로는 알 수 없지만, 2 이상으로 설정하여 클러스터 모드 활성화
+        if (!process.env.instances) {
+            process.env.instances = '2';
+        }
+
+        Logger.print("WHATAP-120", `Node.js cluster mode detected: worker ${cluster.worker.id}`, false);
+    }
+};
+
 /**
  * Check if running in PM2 cluster mode
  * @returns {boolean} - True if PM2 cluster mode
