@@ -219,16 +219,12 @@ function initCtx(req, res) {
             remote_addr = remote_addr.split(',')[0].trim();
         }
         ctx.remoteIp = IPUtil.checkIp4(remote_addr);
-        switch (conf.trace_user_using_type || 3) {
-            case 1:
-                ctx.userid = Long.fromNumber(ctx.remoteIp);
-                break;
-            case 2:
-                // MeterUsers.add(ctx.userid);
-                break;
-            case 3:
+        if(conf.getProperty('trace_user_enabled', true)){
+            if(conf.getProperty('trace_user_using_ip', true)){
+                ctx.userid = ctx.remoteIp;
+            }else{
                 ctx.userid = UserIdUtil.getUserId(req, res, 0);
-                break;
+            }
         }
     } catch (e) {
     }
