@@ -521,6 +521,8 @@ SocketIOObserver.prototype.__initCtx = function(socket, args, emitType, contextI
     const ctx = TraceContextManager.start();
     if (!ctx) return null;
 
+    ctx.service_name = "/socket.io";
+
     var remote_addr;
     var remoteAddress = contextInfo.remoteAddress || (socket && socket.conn && socket.conn.remoteAddress);
 
@@ -530,12 +532,11 @@ SocketIOObserver.prototype.__initCtx = function(socket, args, emitType, contextI
         }
     }
 
-    ctx.service_name = "/socket.io";
-
-    if (remote_addr) {
-        remote_addr = IPUtil.checkIp4(remote_addr);
-        ctx.remoteIp = IPUtil.stringToInt(remote_addr);
-        ctx.userid = ctx.remoteIp;
+    if(remote_addr){
+        ctx.remoteIp = IPUtil.checkIp4(remote_addr);
+        if(conf.getProperty('trace_user_enabled', true)){
+            ctx.userid = ctx.remoteIp;
+        }
     }
 
     // 기본값 설정
